==> py_pdf_term-1.0.0.tar.gz: py_pdf_term-1.0.0/py_pdf_term/endtoend/_endtoend/caches/xml/base.py <==
from abc import ABCMeta, abstractmethod
from typing import Union

from py_pdf_term.pdftoxml import PDFnXMLElement

from ...configs import XMLLayerConfig


class BaseXMLLayerCache(metaclass=ABCMeta):
    """Base class for XML layer caches. An XML layer cache is expected to store and
    load XML elements per a PDF file.

    Args
    ----
        cache_dir:
            The directory path to store cache files.
    """

    def __init__(self, cache_dir: str) -> None:
        pass

    @abstractmethod
    def load(
        self, pdf_path: str, config: XMLLayerConfig
    ) -> Union[PDFnXMLElement, None]:
        """Load XML elements from a cache file.

        Args
        ----
            pdf_path:
                The path to a PDF file to load XML elements.
            config:
                The configuration for the XML layer. The configuration is used to
                determine the cache file path.

        Returns
        -------
            Union[PDFnXMLElement, None]:
                The loaded XML elements. If there is no cache file, this method returns
                None.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.load()")

    @abstractmethod
    def store(self, pdfnxml: PDFnXMLElement, config: XMLLayerConfig) -> None:
        """Store XML elements to a cache file.

        Args
        ----
            pdfnxml:
                The XML elements to store.
            config:
                The configuration for the XML layer. The configuration is used to
                determine the cache file path.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.store()")

    @abstractmethod
    def remove(self, pdf_path: str, config: XMLLayerConfig) -> None:
        """Remove a cache file.

        Args
        ----
            pdf_path:
                The path to a PDF file to remove a cache file.
            config:
                The configuration for the XML layer. The configuration is used to
                determine the cache file path.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.remove()")

==> py_pdf_term-1.0.2.tar.gz: py_pdf_term-1.0.2/py_pdf_term/endtoend/_endtoend/caches/xml/base.py <==
from abc import ABCMeta, abstractmethod

from py_pdf_term.pdftoxml import PDFnXMLElement

from ...configs import XMLLayerConfig


class BaseXMLLayerCache(metaclass=ABCMeta):
    """Base class for XML layer caches. An XML layer cache is expected to store and
    load XML elements per a PDF file.

    Args
    ----
        cache_dir:
            Directory path to store cache files.
    """

    def __init__(self, cache_dir: str) -> None:
        pass

    @abstractmethod
    def load(self, pdf_path: str, config: XMLLayerConfig) -> PDFnXMLElement | None:
        """Load XML elements from a cache file.

        Args
        ----
            pdf_path:
                Path to a PDF file to load XML elements.
            config:
                Configuration for the XML layer. The configuration is used to
                determine the cache file path.

        Returns
        -------
            PDFnXMLElement | None:
                Loaded XML elements. If there is no cache file, this method returns
                None.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.load()")

    @abstractmethod
    def store(self, pdfnxml: PDFnXMLElement, config: XMLLayerConfig) -> None:
        """Store XML elements to a cache file.

        Args
        ----
            pdfnxml:
                The XML elements to store.
            config:
                Configuration for the XML layer. The configuration is used to
                determine the cache file path.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.store()")

    @abstractmethod
    def remove(self, pdf_path: str, config: XMLLayerConfig) -> None:
        """Remove a cache file.

        Args
        ----
            pdf_path:
                Path to a PDF file to remove a cache file.
            config:
                Configuration for the XML layer. The configuration is used to
                determine the cache file path.
        """

        raise NotImplementedError(f"{self.__class__.__name__}.remove()")
